/*
 * digital_clock_mode.cc
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "digital_clock_mode.h"
#include "display.h"
#include "text.h"
#include "text_renderer.h"
#include "time.h"


DigitalClockMode::DigitalClockMode()
	:
	MinorMode( 6 )
{
}


void DigitalClockMode::press()
{
	MinorMode::press();

	set_message( false );
}


void DigitalClockMode::draw( int segment )
{
	Text::draw( 0, segment );
//	Text::draw( 1, segment );
	TextRenderer::output_buffer();
}


void DigitalClockMode::draw_reset()
{
	// gotta update message, the time might have changed!
	set_message( true );

	Text::draw_reset();
}


void DigitalClockMode::activate()
{
	MinorMode::activate();

	Display::leds_off();

	Text::reset();
	set_message( false );
}


void DigitalClockMode::set_message( bool update )
{
	Time &time = Time::get_instance();

	PString str0( Text::_messages[ 0 ], MESSAGE_LEN );
//	PString str1( Text::_messages[ 1 ], MESSAGE_LEN );
	str0.begin();
	str0.print( "1234567890" );
	Text::set_message( 0, str0 );
	if( !update )
		Text::set_message_mode( 0, get_flavour() * 4
								+ Text::MODE_TOP + Text::MODE_HSCROLL );
/*	str1.begin();
	switch( get_flavour() )
	{
	case 0:
		str0.format( "%d:%02d:%02d %s", time.get_hours() % 12,
					time.get_minutes(), time.get_seconds(),
					time.get_hours() / 12 > 0? "pm" : "am" );
		Text::set_message( 0, str0, update? 0 : 'T' );
		str1.print( "-" );
		Text::set_message( 1, str1, update? 0 : 'B' );
		break;
	case 1:
		str0.format( "%d%s %s, %d", time.get_day(),
					time.get_day_suffix(),
					time.get_month_name(), time.get_year() );
		Text::set_message( 0, str0, update? 0 : 'S' );
		Text::set_message( 1, str1, update? 0 : 'b' );
		break;
	}
*/
}
